@@ -3,7 +3,7 @@
 ##----- LOSYME
 ##----- POE::Component::ICal
 ##----- Schedule POE events using rfc2445 recurrences
-##----- tests::tidy
+##----- tidy.pm [t]
 ##
 ########################################################################################################################
 
@@ -24,6 +24,7 @@ our @EXPORT
     t_end
 );
 
+###-------------------------------------------------------------------------------------------------------------------##
 sub import
 {
     my $class = shift;
@@ -46,6 +47,7 @@ sub import
     $class->export_to_level(1, $class, @_);
 }
 
+###-------------------------------------------------------------------------------------------------------------------##
 sub t_start
 {
     plan(tests => 1);
@@ -54,15 +56,16 @@ sub t_start
     ok(1);
 }
 
+###-------------------------------------------------------------------------------------------------------------------##
 sub t_prerequisites
 {
     my $requires;
 
-    if ( -f 'META.yml' )
+    if ( -f './META.yml' )
     {
         eval <<'YAML'
             use YAML;
-            my $prereqs = YAML::LoadFile( 'META.yml' );
+            my $prereqs = YAML::LoadFile( './META.yml' );
             $requires = $prereqs->{requires};
 YAML
     }
@@ -93,6 +96,7 @@ YAML
     ok(1);
 }
 
+###-------------------------------------------------------------------------------------------------------------------##
 sub t_load
 {
     my @modules = @_;
@@ -138,6 +142,7 @@ sub t_load
     diag('-' x ($l_name + $l_version + 13));
 }
 
+###-------------------------------------------------------------------------------------------------------------------##
 sub t_end
 {
     plan(tests => 1);
